ReflectDsl

Struct ReflectDsl 

pub struct ReflectDsl<T: Struct, D: DslBundle = (), F: Format = RonFormat> { /* private fields */ }
Automatic ParseDsl implementation for any Bundle + Reflect struct.

If you find using the parse_dsl_impl macro burdensome, and just want to use any bevy Bundle as a DSL, you can use ReflectDsl to use the struct fields as DSL “methods”, and Reflect deserialization to parse the arguments automatically.

How to use

You have a type as follow:

use cuicui_chirp::ReflectDsl;

#[derive(Bundle, Reflect, Default)]
struct MyBundle {
    transform: Transform,
    visibility: Visibility,
}
// and you did register it with:
app.register_type::<MyBundle>();

You want to use it in a DSL when parsing files. Consider the following chirp file:

entity(row) {
    entity (
        transform (
           translation: (x: 0.0, y: 0.0, z: 0.0),
           rotation: (0.0, 0.0, 0.0, 1.0),
           scale: (x: 1.0, y: 1.0, z: 1.0),
         ),
         visibility Inherited,
    );
}

You want both LayoutDsl methods and fields of MyBundle to work in your chirp files.

In order to do that, you should add the loader for the correct DSL as follow:

use cuicui_chirp::ReflectDsl;

// Add `ReflectDsl<MyBundle, _>` as an extension on the `LayoutDsl` DSL.
type Dsl = ReflectDsl<MyBundle, LayoutDsl>;
app.add_plugins((
    // ...
    // The loader now recognizes the methods `transform` and `visibility`.
    // They were fields of `MyBundle`
    cuicui_chirp::loader::Plugin::new::<Dsl>(),
));

Caveats

This doesn’t work with the dsl! macro. You can only use ReflectDsl with scenes defined in chirp files.